==> reverse_api_engineer-0.2.0.tar.gz: reverse_api_engineer-0.2.0/src/reverse_api/utils.py <==
"""Utility functions for run ID generation and path management."""

import asyncio
import re
import uuid
from datetime import datetime
from pathlib import Path


def generate_folder_name(prompt: str) -> str:
    """Generate a clean folder name from a prompt using Claude Haiku.

    Uses Claude Agent SDK with claude-haiku-4-5 model to generate a short, descriptive name.
    Falls back to simple slugification if API call fails.
    """
    try:
        return asyncio.run(_generate_folder_name_async(prompt))
    except Exception:
        pass

    # Fallback: simple slugify
    return _slugify(prompt)


async def _generate_folder_name_async(prompt: str) -> str:
    """Async helper to generate folder name using Claude Agent SDK."""
    from claude_agent_sdk import ClaudeSDKClient, ClaudeAgentOptions, AssistantMessage, TextBlock

    options = ClaudeAgentOptions(
        allowed_tools=[],  # No tools needed for simple text generation
        permission_mode="dontAsk",
        model="claude-haiku-4-5",
    )

    folder_name = ""

    async with ClaudeSDKClient(options=options) as client:
        await client.query(
            f"Generate a short folder name (1-3 words, lowercase, underscores) for this task: {prompt}\n\n"
            f"Respond with ONLY the folder name, nothing else. Example: apple_jobs_api"
        )

        async for message in client.receive_response():
            if isinstance(message, AssistantMessage):
                for block in message.content:
                    if isinstance(block, TextBlock):
                        folder_name = block.text.strip().lower()
                        break

    # Clean up the name to be filesystem-safe
    name = re.sub(r'[^a-z0-9_]', '_', folder_name)
    name = re.sub(r'_+', '_', name)  # Collapse multiple underscores
    name = name.strip('_')[:50]  # Limit length

    return name if name else _slugify(prompt)


def _slugify(text: str) -> str:
    """Simple slugify fallback - converts text to a filesystem-safe name."""
    text = text.lower()
    text = re.sub(r'[^a-z0-9\s]', '', text)
    text = re.sub(r'\s+', '_', text)
    words = text.split('_')[:3]  # Take first 3 words
    return '_'.join(words)[:50]


def generate_run_id() -> str:
    """Generate a unique run ID using a short UUID format."""
    return uuid.uuid4().hex[:12]


def get_project_root() -> Path:
    """Get the project root directory."""
    return Path(__file__).parent.parent.parent


def get_app_dir() -> Path:
    """Get the central application data directory."""
    app_dir = Path.home() / ".reverse-api"
    app_dir.mkdir(parents=True, exist_ok=True)
    return app_dir


def get_config_path() -> Path:
    """Get the path to the config file."""
    return get_app_dir() / "config.json"


def get_history_path() -> Path:
    """Get the path to the history file."""
    return get_app_dir() / "history.json"


def get_base_output_dir(output_dir: str | None = None) -> Path:
    """Get the base directory for outputs (HARs and scripts)."""
    if output_dir:
        return Path(output_dir)
    return get_app_dir() / "runs"


def get_har_dir(run_id: str, output_dir: str | None = None) -> Path:
    """Get the HAR directory for a specific run."""
    base_dir = get_base_output_dir(output_dir)
    har_dir = base_dir / "har" / run_id
    har_dir.mkdir(parents=True, exist_ok=True)
    return har_dir


def get_scripts_dir(run_id: str, output_dir: str | None = None) -> Path:
    """Get the scripts directory for a specific run."""
    base_dir = get_base_output_dir(output_dir)
    scripts_dir = base_dir / "scripts" / run_id
    scripts_dir.mkdir(parents=True, exist_ok=True)
    return scripts_dir


def get_messages_path(run_id: str, output_dir: str | None = None) -> Path:
    """Get the messages file path for a specific run."""
    base_dir = get_base_output_dir(output_dir)
    messages_dir = base_dir / "messages"
    messages_dir.mkdir(parents=True, exist_ok=True)
    return messages_dir / f"{run_id}.jsonl"


def get_timestamp() -> str:
    """Get current timestamp in ISO format."""
    return datetime.now().isoformat()

==> reverse_api_engineer-0.2.4.tar.gz: reverse_api_engineer-0.2.4/src/reverse_api/utils.py <==
"""Utility functions for run ID generation and path management."""

import asyncio
import re
import uuid
from datetime import datetime
from pathlib import Path


def generate_folder_name(prompt: str) -> str:
    """Generate a clean folder name from a prompt using Claude Haiku.

    Uses Claude Agent SDK with claude-haiku-4-5 model to generate a short, descriptive name.
    Falls back to simple slugification if API call fails.
    """
    try:
        return asyncio.run(_generate_folder_name_async(prompt))
    except Exception:
        pass

    # Fallback: simple slugify
    return _slugify(prompt)


async def _generate_folder_name_async(prompt: str) -> str:
    """Async helper to generate folder name using Claude Agent SDK."""
    import logging
    from claude_agent_sdk import ClaudeSDKClient, ClaudeAgentOptions, AssistantMessage, TextBlock

    # Suppress claude_agent_sdk logs
    logging.getLogger("claude_agent_sdk").setLevel(logging.WARNING)
    logging.getLogger("claude_agent_sdk._internal.transport.subprocess_cli").setLevel(logging.WARNING)

    options = ClaudeAgentOptions(
        allowed_tools=[],  # No tools needed for simple text generation
        permission_mode="dontAsk",
        model="claude-haiku-4-5",
    )

    folder_name = ""

    async with ClaudeSDKClient(options=options) as client:
        await client.query(
            f"Generate a short folder name (1-3 words, lowercase, underscores) for this task: {prompt}\n\n"
            f"Respond with ONLY the folder name, nothing else. Example: apple_jobs_api"
        )

        async for message in client.receive_response():
            if isinstance(message, AssistantMessage):
                for block in message.content:
                    if isinstance(block, TextBlock):
                        folder_name = block.text.strip().lower()
                        break

    # Clean up the name to be filesystem-safe
    name = re.sub(r'[^a-z0-9_]', '_', folder_name)
    name = re.sub(r'_+', '_', name)  # Collapse multiple underscores
    name = name.strip('_')[:50]  # Limit length

    return name if name else _slugify(prompt)


def _slugify(text: str) -> str:
    """Simple slugify fallback - converts text to a filesystem-safe name."""
    text = text.lower()
    text = re.sub(r'[^a-z0-9\s]', '', text)
    text = re.sub(r'\s+', '_', text)
    words = text.split('_')[:3]  # Take first 3 words
    return '_'.join(words)[:50]


def generate_run_id() -> str:
    """Generate a unique run ID using a short UUID format."""
    return uuid.uuid4().hex[:12]


def get_project_root() -> Path:
    """Get the project root directory."""
    return Path(__file__).parent.parent.parent


def get_app_dir() -> Path:
    """Get the central application data directory."""
    app_dir = Path.home() / ".reverse-api"
    app_dir.mkdir(parents=True, exist_ok=True)
    return app_dir


def get_config_path() -> Path:
    """Get the path to the config file."""
    return get_app_dir() / "config.json"


def get_history_path() -> Path:
    """Get the path to the history file."""
    return get_app_dir() / "history.json"


def get_base_output_dir(output_dir: str | None = None) -> Path:
    """Get the base directory for outputs (HARs and scripts)."""
    if output_dir:
        return Path(output_dir)
    return get_app_dir() / "runs"


def get_har_dir(run_id: str, output_dir: str | None = None) -> Path:
    """Get the HAR directory for a specific run."""
    base_dir = get_base_output_dir(output_dir)
    har_dir = base_dir / "har" / run_id
    har_dir.mkdir(parents=True, exist_ok=True)
    return har_dir


def get_scripts_dir(run_id: str, output_dir: str | None = None) -> Path:
    """Get the scripts directory for a specific run."""
    base_dir = get_base_output_dir(output_dir)
    scripts_dir = base_dir / "scripts" / run_id
    scripts_dir.mkdir(parents=True, exist_ok=True)
    return scripts_dir


def get_messages_path(run_id: str, output_dir: str | None = None) -> Path:
    """Get the messages file path for a specific run."""
    base_dir = get_base_output_dir(output_dir)
    messages_dir = base_dir / "messages"
    messages_dir.mkdir(parents=True, exist_ok=True)
    return messages_dir / f"{run_id}.jsonl"


def get_timestamp() -> str:
    """Get current timestamp in ISO format."""
    return datetime.now().isoformat()
